﻿;========================================================================================================================================
; Create the program constants file
;========================================================================================================================================

Procedure MyConstantsFile()
  
  ;----------------------------------------------------------------------------------------------
  ; Proceed if there is a predefined project directory
  ;----------------------------------------------------------------------------------------------
  
  OutputFileName.s = Program\ProjectDirectory + Program\ProjectName + "_Myconstants.pb"
  
  ;----------------------------------------------------------------------------------------------
  ; Proceed if the user selected a file to save to
  ;----------------------------------------------------------------------------------------------
  
  If OutputFileName.s
    
    ;--------------------------------------------------------------------------------------------
    ; Create the output file to save to
    ;--------------------------------------------------------------------------------------------
    
    OutputFileHandle.i = CreateFile(#PB_Any, OutputFileName.s)
    
    ;--------------------------------------------------------------------------------------------
    ; Proceed if we got a valid file handle for the output file
    ;--------------------------------------------------------------------------------------------
    
    If OutputFileHandle.i
      
      ;------------------------------------------------------------------------------------------
      ; Need a unicode aware version of the API directory creator for the output code to use. This
      ; is for the program to create directories for itself as needed.
      ;------------------------------------------------------------------------------------------
      
      WriteHeadingToOutputFile(OutputFileHandle.i, "; Need a unicode aware version of the API directory creator")
      
      WriteStringN(OutputFileHandle.i, "Import " + Chr(34) + "shell32.lib" + Chr(34))                                            ; ")
      
      WriteStringN(OutputFileHandle.i, "  SHCreateDirectory(*hwnd, pszPath.p-unicode)")                                          ; ")
      
      WriteStringN(OutputFileHandle.i, "EndImport")                                                                              ; ")
      
      ;------------------------------------------------------------------------------------------
      ; Generic data structures to store all of my commonly used program variables that I use for
      ; I use for each program that I write
      ;------------------------------------------------------------------------------------------
      
      WriteHeadingToOutputFile(OutputFileHandle.i, "; Generic program data structures")
      
      WriteStringN(OutputFileHandle.i, "Structure ProgramData                                                                   ; Program data structure")
      
      WriteStringN(OutputFileHandle.i, "  QuitValue.i                                                                           ; Program quit value")
      
      WriteStringN(OutputFileHandle.i, "  WindowMutex.i                                                                         ; Window lock mutex")
      
      WriteStringN(OutputFileHandle.i, "  LastWindow.s                                                                          ; The last window opened")
      
      WriteStringN(OutputFileHandle.i, "  CurrentLine.i                                                                         ; Currently selected line")
      
      WriteStringN(OutputFileHandle.i, "")
      
      WriteStringN(OutputFileHandle.i, "  CurrentDirectory.s                                                                    ; Current program directory")
      
      WriteStringN(OutputFileHandle.i, "  ImageDirectory.s                                                                      ; Current program image directory")
      
      WriteStringN(OutputFileHandle.i, "  IncludeDirectory.s                                                                    ; Current program include files")
      
      WriteStringN(OutputFileHandle.i, "EndStructure                                                                            ; ")
      
      ;------------------------------------------------------------------------------------------
      ; Tooltip data tracking structure I use for each program that I write
      ;------------------------------------------------------------------------------------------
      
      WriteHeadingToOutputFile(OutputFileHandle.i, "; Tooltip structure data")
      
      WriteStringN(OutputFileHandle.i, "Structure ToolTipData                                                                     ; If any tooltips setup, keep track of gadgets that have them so you can remove them if needed")
      
      WriteStringN(OutputFileHandle.i, "  Window.i                                                                                ; Window being added to")
      
      WriteStringN(OutputFileHandle.i, "  Gadget.i                                                                                ; Gadget being added to on the window")
      
      WriteStringN(OutputFileHandle.i, "  Handle.i                                                                                ; Handle of the new tooltip")
      
      WriteStringN(OutputFileHandle.i, "EndStructure                                                                              ; ")
      
      ;------------------------------------------------------------------------------------------
      ; Create working directory variables for the new program
      ;------------------------------------------------------------------------------------------
      
      WriteHeadingToOutputFile(OutputFileHandle.i, "; Get working directories")
      
      WriteStringN(OutputFileHandle.i, "Program\CurrentDirectory    = GetCurrentDirectory()")                                   ; Get the current working directory
      
      WriteStringN(OutputFileHandle.i, "Program\ProjectDirectory    = Program\CurrentDirectory + " + Chr(34) + "Project\"  + Chr(34))                    ;
      
      WriteStringN(OutputFileHandle.i, "Program\ImageDirectory      = Program\ProjectDirectory + " + Chr(34) + "Images\"   + Chr(34))                    ; 
      
      WriteStringN(OutputFileHandle.i, "Program\ModuleDirectory     = Program\ProjectDirectory + " + Chr(34) + "Includes\" + Chr(34))                    ; 
      
      ;------------------------------------------------------------------------------------------
      ; Create the program's working directories if you can from the previously created variables
      ;------------------------------------------------------------------------------------------
      
      WriteHeadingToOutputFile(OutputFileHandle.i, "; Create the program's working directories if you can")
      
      WriteStringN(OutputFileHandle.i, "MakeSureDirectoryPathExists(Program\ProjectDirectory)                                     ; ")
      
      WriteStringN(OutputFileHandle.i, "MakeSureDirectoryPathExists(Program\ImageDirectory)                                       ; ")
      
      WriteStringN(OutputFileHandle.i, "MakeSureDirectoryPathExists(Program\ModuleDirectory)                                      ; ")
      
      ;------------------------------------------------------------------------------------------
      ; Keyboard shortcut data structure holder for the raw value. I.e: if you had pressed 
      ; CTRL + B, the raw value would be 131138. I always write out the key press than generated
      ; this behind semi colons to remind me.
      ;------------------------------------------------------------------------------------------
      
      WriteHeadingToOutputFile(OutputFileHandle.i, "; Keyboard shortcut data structure holder")
      
      WriteStringN(OutputFileHandle.i, FormatField("Structure KeyData", 32) + FormatField("; Key Text", 20) +  FormatField("; Key value", 20) +  FormatField("; Key pair", 15) +  FormatField("; Balloon text", 50))
      
      ForEach Keys.s()
        
        If Left(Keys()\KeyDataName, 1) <> "~" And Right(Keys()\KeyDataName, 1) <> "~"
          
          ;--------------------------------------------------------------------------------------
          ; This is the data that we are going to write
          ;--------------------------------------------------------------------------------------
          
          WriteString(OutputFileHandle.i, "  " +  FormatField(Keys()\KeyDataText + ".i",   30))     ; Short form variable to be used as shortcut structure item
          
          ;--------------------------------------------------------------------------------------
          ; These are just reminder strings to help us
          ;--------------------------------------------------------------------------------------
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteString(OutputFileHandle.i,         FormatField(Keys()\KeyDataName,          20))     ; Long form variable to be used as menu text
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteString(OutputFileHandle.i,         FormatField(Keys()\KeyDataValue,         20))     ; Decimal value of the pressed shortcut keys
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteString(OutputFileHandle.i,         FormatField(Keys()\KeyDataKeys,          15))     ; The pressed shortcut keys in text form
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteStringN(OutputFileHandle.i,        FormatField(Keys()\KeyDataBalloon,       50))     ; Balloon tooltip text
          
        Else
          
          WriteStringN(OutputFileHandle.i, "; " + ReplaceString(Keys()\KeyDataName, "~", "") + " Menu")
          
        EndIf
        
      Next 
      
      WriteStringN(OutputFileHandle.i, "EndStructure")
      
      ;------------------------------------------------------------------------------------------
      ; Keyboard shortcut data structure holder for the keyboard shortcut variable names. This
      ; usually appears in the menu of a program to tell you what that option is.
      ;------------------------------------------------------------------------------------------
      
      WriteHeadingToOutputFile(OutputFileHandle.i, "; Keyboard shortcuts text holders")
      
      WriteStringN(OutputFileHandle.i, FormatField("Structure MenuTextData", 32) +  FormatField("; Key Text", 20) +  FormatField("; Key value", 20) +  FormatField("; Key pair", 15) +  FormatField("; Balloon text", 50))
      
      ForEach Keys.s()
        
        If Left(Keys()\KeyDataName, 1) <> "~" And Right(Keys()\KeyDataName, 1) <> "~"
          
          ;--------------------------------------------------------------------------------------
          ; This is the data that we are going to write
          ;--------------------------------------------------------------------------------------
          
          WriteString(OutputFileHandle.i, "  " +  FormatField(Keys()\KeyDataText + ".s",   30))     ; Short form variable to be used as shortcut structure item
          
          ;--------------------------------------------------------------------------------------
          ; These are just reminder strings to help us
          ;--------------------------------------------------------------------------------------
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteString(OutputFileHandle.i,         FormatField(Keys()\KeyDataName,          20))     ; Long form variable to be used as menu text
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteString(OutputFileHandle.i,         FormatField(Keys()\KeyDataValue,         20))     ; Decimal value of the pressed shortcut keys
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteString(OutputFileHandle.i,         FormatField(Keys()\KeyDataKeys,          15))     ; The pressed shortcut keys in text form
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteStringN(OutputFileHandle.i,        FormatField(Keys()\KeyDataBalloon,       50))     ; Balloon tooltip text
          
        Else
          
          WriteStringN(OutputFileHandle.i, "; " + ReplaceString(Keys()\KeyDataName, "~", "") + " Menu")
          
        EndIf
        
      Next
      
      WriteStringN(OutputFileHandle.i, "EndStructure")
      
      ;------------------------------------------------------------------------------------------
      ; Keyboard shortcut data structure holder for the keyboard shortcut variable names. This
      ; usually appears in the menu of a program to tell you what that option is.
      ;------------------------------------------------------------------------------------------
      
      WriteHeadingToOutputFile(OutputFileHandle.i, "; Balloon tooltips text holders")
      
      WriteStringN(OutputFileHandle.i, FormatField("Structure BalloonTipData", 32) +  FormatField("; Key Text", 20) +  FormatField("; Key value", 20) +  FormatField("; Key pair", 15) +  FormatField("; Balloon text", 50))
      
      ForEach Keys.s()
        
        If Left(Keys()\KeyDataName, 1) <> "~" And Right(Keys()\KeyDataName, 1) <> "~"
          
          ;--------------------------------------------------------------------------------------
          ; This is the data that we are going to write
          ;--------------------------------------------------------------------------------------
          
          WriteString(OutputFileHandle.i, "  " +  FormatField(Keys()\KeyDataText + ".s",   30))     ; Short form variable to be used as shortcut structure item
          
          ;--------------------------------------------------------------------------------------
          ; These are just reminder strings to help us
          ;--------------------------------------------------------------------------------------
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteString(OutputFileHandle.i,         FormatField(Keys()\KeyDataName,          20))     ; Long form variable to be used as menu text
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteString(OutputFileHandle.i,         FormatField(Keys()\KeyDataValue,         20))     ; Decimal value of the pressed shortcut keys
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteString(OutputFileHandle.i,         FormatField(Keys()\KeyDataKeys,          15))     ; The pressed shortcut keys in text form
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteStringN(OutputFileHandle.i,        FormatField(Keys()\KeyDataBalloon,       50))     ; Balloon toltip text
          
        Else
          
          WriteStringN(OutputFileHandle.i, "; " + ReplaceString(Keys()\KeyDataName, "~", "") + " Menu")
          
        EndIf
        
      Next
      
      WriteStringN(OutputFileHandle.i, "EndStructure")
      
      ;------------------------------------------------------------------------------------------
      ; Global structure declarations, these are generally the ones I use.
      ;------------------------------------------------------------------------------------------
      
      WriteHeadingToOutputFile(OutputFileHandle.i, "; Global variables")
      
      WriteStringN(OutputFileHandle.i, "Global Program.ProgramData                                                           ; All my program variables")
      
      WriteStringN(OutputFileHandle.i, "Global Keys.KeyData                                                                  ; All my keyboard shortcuts")
      
      WriteStringN(OutputFileHandle.i, "Global MenuText.MenuTextData                                                         ; All repeated menu texts")
      
      WriteStringN(OutputFileHandle.i, "Global ToolTip.BalloonTipData                                                        ; All repeated balloon tip texts")
      
      ;------------------------------------------------------------------------------------------
      ; Full keyboard shortcut menu text explanations
      ;------------------------------------------------------------------------------------------
      
      WriteHeadingToOutputFile(OutputFileHandle.i, "; Short form keyboard shortcut menu text explanations")
      
      ForEach Keys.s()
        
        If Left(Keys()\KeyDataName, 1) <> "~" And Right(Keys()\KeyDataName, 1) <> "~"
          
          ;--------------------------------------------------------------------------------------
          ; This is the data that we are going to write
          ;--------------------------------------------------------------------------------------
          
          WriteString(OutputFileHandle.i,         FormatField("MenuText\" + Keys()\KeyDataText, 30)  + " = " )
          
          WriteString(OutputFileHandle.i,         FormatField(Chr(34) + Keys()\KeyDataName + Chr(34), 20))
          
          ;--------------------------------------------------------------------------------------
          ; These are just reminder strings to help us
          ;--------------------------------------------------------------------------------------
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteString(OutputFileHandle.i,         FormatField(Keys()\KeyDataName,          20))     ; Long form variable to be used as menu text
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteString(OutputFileHandle.i,         FormatField(Keys()\KeyDataValue,         20))     ; Decimal value of the pressed shortcut keys
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteString(OutputFileHandle.i,         FormatField(Keys()\KeyDataKeys,          15))     ; The pressed shortcut keys in text form
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteStringN(OutputFileHandle.i,        FormatField(Keys()\KeyDataBalloon,       50))     ; Balloon tooltip text
          
        Else
          
          WriteStringN(OutputFileHandle.i, "; " + ReplaceString(Keys()\KeyDataName, "~", "") + " Menu")
          
        EndIf
        
      Next
      
      ;------------------------------------------------------------------------------------------
      ; Full balloon tooltip explanation text
      ;------------------------------------------------------------------------------------------
      
      WriteHeadingToOutputFile(OutputFileHandle.i, "; Long winded balloon tooltip text")
      
      ForEach Keys.s()
        
        If Left(Keys()\KeyDataName, 1) <> "~" And Right(Keys()\KeyDataName, 1) <> "~"
          
          ;--------------------------------------------------------------------------------------
          ; This is the data that we are going to write
          ;--------------------------------------------------------------------------------------
          
          WriteString(OutputFileHandle.i,         FormatField("BalloonText\" + Keys()\KeyDataText, 30)  + " = " )
          
          WriteString(OutputFileHandle.i,         FormatField(Chr(34) + Keys()\KeyDataBalloon + Chr(34), 68))
          
          ;--------------------------------------------------------------------------------------
          ; These are just reminder strings to help us
          ;--------------------------------------------------------------------------------------
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteString(OutputFileHandle.i,         FormatField(Keys()\KeyDataName,          20))     ; Long form variable to be used as menu text
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteString(OutputFileHandle.i,         FormatField(Keys()\KeyDataValue,         20))     ; Decimal value of the pressed shortcut keys
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteString(OutputFileHandle.i,         FormatField(Keys()\KeyDataKeys,          15))     ; The pressed shortcut keys in text form
          
          WriteString(OutputFileHandle.i, "; ")
          
          WriteStringN(OutputFileHandle.i,        FormatField(Keys()\KeyDataBalloon,       50))     ; Balloon tooltip text
          
        Else
          
          WriteStringN(OutputFileHandle.i, "; " + ReplaceString(Keys()\KeyDataName, "~", "") + " Menu")
          
        EndIf
        
      Next
      
      ;------------------------------------------------------------------------------------------
      ; Write the shortcut keys datasection #ShortCut_ + Keys()\KeyDataName
      ;------------------------------------------------------------------------------------------
      
      WriteHeadingToOutputFile(OutputFileHandle.i, "; Keyboard shortcuts data section")
      
      WriteStringN(OutputFileHandle.i,            "Enumeration #GadgetIndex")
      
      WriteStringN(OutputFileHandle.i, BlankLine.s)
      
      WriteStringN(OutputFileHandle.i,            "  ; Main program GUI shortcuts")
      
      WriteStringN(OutputFileHandle.i, BlankLine.s)
      
      ForEach Keys.s()
        
        If Left(Keys()\KeyDataName, 1) <> "~" And Right(Keys()\KeyDataName, 1) <> "~"
          
          WriteStringN(OutputFileHandle.i,          "  #ShortCut_" + Keys()\KeyDataText)
          
        Else
          
          WriteStringN(OutputFileHandle.i, "; " + ReplaceString(Keys()\KeyDataText, "~", "") + " Menu")
          
        EndIf
        
      Next
      
      WriteStringN(OutputFileHandle.i, BlankLine.s)
      
      WriteStringN(OutputFileHandle.i,            "  ; Main program GUI menubar constants")
      
      WriteStringN(OutputFileHandle.i, BlankLine.s)
      
      ForEach Keys.s()
        
        If Left(Keys()\KeyDataName, 1) <> "~" And Right(Keys()\KeyDataName, 1) <> "~"
          
          WriteStringN(OutputFileHandle.i,          "  #MenuBar_" + Keys()\KeyDataText)
          
        Else
          
          WriteStringN(OutputFileHandle.i, "; " + ReplaceString(Keys()\KeyDataText, "~", "") + " Menu")
          
        EndIf
        
      Next
      
      WriteStringN(OutputFileHandle.i,            "EndEnumeration")
      
      ;------------------------------------------------------------------------------------------
      ; Menubar icon image constants heading
      ;------------------------------------------------------------------------------------------
      
      WriteHeadingToOutputFile(OutputFileHandle.i, "; Menubar icon image constants")
      
      WriteStringN(OutputFileHandle.i,            "Enumeration #ImageIndex")
      
      WriteStringN(OutputFileHandle.i, BlankLine.s)
      
      WriteStringN(OutputFileHandle.i,            "  ; Main program MenuBar icon constants")
      
      WriteStringN(OutputFileHandle.i, BlankLine.s)
      
      ForEach Keys.s()
        
        If Left(Keys()\KeyDataName, 1) <> "~" And Right(Keys()\KeyDataName, 1) <> "~"
          
          WriteStringN(OutputFileHandle.i,          "  #MenuBarIcon_" + Keys()\KeyDataText)
          
        Else
          
          WriteStringN(OutputFileHandle.i, "; " + ReplaceString(Keys()\KeyDataText, "~", "") + " Menu")
          
        EndIf
        
      Next
      
      WriteStringN(OutputFileHandle.i,            "EndEnumeration")
      
      ;------------------------------------------------------------------------------------------
      ; Load the menuBar icon images heading
      ;------------------------------------------------------------------------------------------
      
      WriteHeadingToOutputFile(OutputFileHandle.i, "; Menubar icon images")
      
      ForEach Keys.s()
        
        If Left(Keys()\KeyDataName, 1) <> "~" And Right(Keys()\KeyDataName, 1) <> "~"
          
          WriteStringN(OutputFileHandle.i, FormatField("CatchImage(#MenuBarIcon_" + Keys()\KeyDataText + ",", 67) + "?_MenuBarIcon_" + Keys()\KeyDataText + ")")
          
        Else
          
          WriteStringN(OutputFileHandle.i, "; " + ReplaceString(Keys()\KeyDataText, "~", "") + " Menu")
          
        EndIf
        
      Next
      
      ;------------------------------------------------------------------------------------------
      ; DataSection for image includes heading
      ;------------------------------------------------------------------------------------------
      
      WriteHeadingToOutputFile(OutputFileHandle.i, "; Menubar icon images")
      
      WriteStringN(OutputFileHandle.i, "DataSection")
        
      ForEach Keys.s()
        
        If Left(Keys()\KeyDataName, 1) <> "~" And Right(Keys()\KeyDataName, 1) <> "~"
          
          WriteStringN(OutputFileHandle.i, FormatField("  _MenuBarIcon_" + Keys()\KeyDataText + ":", 50) + "IncludeBinary  " + Chr(34) + "Images\MenuBarIcon_" + Keys()\KeyDataText + ".ico" + Chr(34))
          
        Else
          
          WriteStringN(OutputFileHandle.i, "; " + ReplaceString(Keys()\KeyDataText, "~", "") + " Menu")
          
        EndIf
        
      Next
      
      WriteStringN(OutputFileHandle.i, "EndDataSection")
      
      ;------------------------------------------------------------------------------------------
      ; Close the output file as we are finished writing to it
      ;------------------------------------------------------------------------------------------
      
      CloseFile(OutputFileHandle.i)
      
    Else
      
      SetGadgetText(#Gadget_ShortCutter_messages, Str(OutputFileHandle.i) + " could not be created.")
      
    EndIf
    
  Else
    
    SetGadgetText(#Gadget_ShortCutter_messages, OutputFileName.s + " does not exist.")
    
  EndIf
  
  ;----------------------------------------------------------------------------------------------
  ; 
  ;----------------------------------------------------------------------------------------------

EndProcedure

; IDE Options = PureBasic 5.11 (Windows - x86)
; CursorPosition = 504
; FirstLine = 476
; Folding = -
; EnableXP