;===========================================================================================================================
; 'Editable ListIcon'.
;===========================================================================================================================
;
; Stephen Rodriguez.
; Created with Purebasic 4.02 for Windows.
;
; Date:  May 2007.
;
; Platforms:  Windows.
;
; Licence: DAYLike
;   (Do As You Like with it! - No Warranties!)
;   A credit to myself, whilst nice, is not absolutely necessary.
;
;
; NOTES.
; ------
; 1)  Register a listicon gadget to have editable cells by using the command SetListIconEditable(listID).
;     You MUST set up such listicons to have a column zero of zero width.
; 2)  Cells are made editable by intercepting double-clicks, setting the #LVS_EDITLABELS style,
;     repositioning the edit control which Windows uses to edit the labels in column zero and copying
;     the resulting text to the listicon cell.
; 3)  Cells can also be edited by means of the command EditCell().
;

;===========================================================================================================================
; 
;===========================================================================================================================

#LVM_SUBITEMHITTEST = #LVM_FIRST + 57
#LVM_GETSUBITEMRECT = #LVM_FIRST + 56
#LVM_GETHEADER      = #LVM_FIRST + 31
#EC_RIGHTMARGIN     = 2

;===========================================================================================================================
; 
;===========================================================================================================================

EnableExplicit

;===========================================================================================================================
; 
;===========================================================================================================================

DeclareDLL.i SetListIconEditable(listID)

Declare.i   _LIEwinProc(hWnd, uMsg, wParam, lParam)

Declare.i   _LIEListProc(hWnd, uMsg, wParam, lParam)

Declare.i   _LIEeditProc(hWnd, uMsg, wParam, lParam)

;===========================================================================================================================
; 
;===========================================================================================================================

Structure _LIEdit
  listOldProc.i
  editHwnd.i
  item.i
  subitem.i
  x.i
  y.i
  cx.i
  cy.i
EndStructure

;Returns zero if an error.

;===========================================================================================================================
; 
;===========================================================================================================================

ProcedureDLL.i SetListIconEditable(listID)
  
  Protected result, parenthWnd, *mem._LIEdit, hWnd
  
  If IsGadget(listID) And GadgetType(listID) = #PB_GadgetType_ListIcon                     ; Check that listID references a valid listicon.
    
    hWnd = GadgetID(listID)
    
    If GetProp_(hWnd, "_LIEdit") = 0                                                        ; No!;Is the listicon already registered?
      
      *mem = AllocateMemory(SizeOf(_LIEdit))                                              ; Allocate enough memory for a _LIEdit structure.
      
      If *mem
        
        SetWindowLongPtr_(hWnd, #GWL_STYLE, GetWindowLongPtr_(hWnd, #GWL_STYLE) &~ #LVS_EDITLABELS)
        
        *mem\listOldProc = SetWindowLongPtr_(hWnd, #GWL_WNDPROC, @_LIEListProc())            ; Set the fields of the _LIEedit structure.
        
        SetProp_(hWnd, "_LIEdit", *mem)                                                   ; Store a pointer to this structure in a window property ofthe listicon.         
        
        parenthWnd = GetParent_(hWnd)                                                     ; Subclass the parent window if not already through another listicon.
        
        If GetProp_(parenthWnd, "_LIEditOldProc") = 0                                     ; No!
          
          SetProp_(parenthWnd, "_LIEditOldProc", SetWindowLongPtr_(parenthWnd, #GWL_WNDPROC, @_LIEwinProc()))
          
        EndIf
        
        result = 1
        
      EndIf
      
    EndIf
    
  EndIf
  
  ProcedureReturn result
  
EndProcedure

;===========================================================================================================================
; Sets the specified cell to be edited.
;===========================================================================================================================

ProcedureDLL EditCell(listID, item, subitem)
  
  Protected hWnd, *liedit._LIEdit, numrows, numcols
  
  If IsGadget(listID) And GadgetType(listID) = #PB_GadgetType_ListIcon                        ; Check that listID references a valid listicon.
    
    hWnd = GadgetID(listID)                                                               ; Check that the listicon is registered as editable.
    
    *liedit = GetProp_(hWnd, "_LIEdit")
    
    If *liedit
      
      numrows = CountGadgetItems(listID)                                                ; Check parameters are in range.
      
      numcols = SendMessage_(SendMessage_(hWnd, #LVM_GETHEADER, 0, 0), #HDM_GETITEMCOUNT, 0, 0)
      
      If item > = 0 And item < numrows And subitem > 0 And subitem < numcols
        
        *liedit\item = item
        
        *liedit\subitem = subitem
        
        SetWindowLongPtr_(hWnd, #GWL_STYLE, GetWindowLongPtr_(hWnd, #GWL_STYLE) | #LVS_EDITLABELS)
        
        SetActiveGadget(listID)
        
        SendMessage_(hWnd, #LVM_EDITLABEL, item, 0)
        
      EndIf
      
    EndIf
    
  EndIf
  
EndProcedure

;===========================================================================================================================
; Window proc of the ListIcon parent window.
;===========================================================================================================================

Procedure.i _LIEwinProc(hWnd, uMsg, wParam, lParam)
  
  Protected result, oldwinproc, *nmh. NMHDR, listhWnd, edithWnd, *liedit._LIEdit, *lvd.LV_DISPINFO, rc.RECT
  
  Static celltext$
  
  oldwinproc = GetProp_(hWnd, "_LIEditOldProc")                                               ; Retrieve the address of the old proc.
  
  Select uMsg
      
    Case #WM_NOTIFY
      
      *nmh = lParam
      
      Select *nmh\code
          
        Case #LVN_BEGINLABELEDIT
          
          listhWnd = *nmh\hwndFrom
          
          *liedit = GetProp_(listhWnd, "_LIEdit")                                           ; Retrieve the address of the LIEdit structure.
          
          If *liedit                                                                        ; Good to go!
            
            *liedit\editHwnd = 0
            
            edithWnd = SendMessage_(listhWnd, #LVM_GETEDITCONTROL, 0, 0)                  ; Get the handle of the edit control used to edit the label.
            
            SetProp_(edithWnd, "_LIEditOldProc", SetWindowLongPtr_(edithWnd, #GWL_WNDPROC, @_LIEeditProc()))               ;Subclass the edit control.
            
            celltext$ = GetGadgetItemText(*nmh\idFrom, *liedit\item, *liedit\subitem)       ; Set text.
            
            SendMessage_(edithWnd, #WM_SETTEXT, 0, celltext$)
            
            SetGadgetItemText(*nmh\idFrom, *liedit\item, "", *liedit\subitem)
            
            rc\top = *liedit\subitem                                                      ; Get bounding rectangle.
            
            rc\left = #LVIR_BOUNDS
            
            SendMessage_(listhWnd, #LVM_GETSUBITEMRECT, *liedit\item, rc)
            
            *liedit\x = rc\left
            
            *liedit\y = rc\top
            
            *liedit\cx = SendMessage_(listhWnd, #LVM_GETCOLUMNWIDTH, *liedit\subitem, 0)
            
            *liedit\cy = rc\bottom - rc\top
            
          EndIf
          
        Case #LVN_ENDLABELEDIT
          
          listhWnd = *nmh\hwndFrom
          
          *liedit = GetProp_(listhWnd, "_LIEdit")                                           ; Retrieve the address of the LIEdit structure.
          
          If *liedit                                                                        ; Good to go!
            
            *lvd = lParam
            
            If *lvd\item\pszText
              
              SetGadgetItemText(*nmh\idFrom, *liedit\item, PeekS(*lvd\item\pszText), *liedit\subitem)
              
            Else             
              
              SetGadgetItemText(*nmh\idFrom, *liedit\item, celltext$, *liedit\subitem)
              
            EndIf
            
            SetWindowLongPtr_(listhWnd, #GWL_STYLE, GetWindowLongPtr_(listhWnd, #GWL_STYLE) &~ #LVS_EDITLABELS)
            
          EndIf
          
        Default
          
          result=CallWindowProc_(oldwinproc, hWnd, uMsg, wParam, lParam)
          
      EndSelect
      
    Case #WM_NCDESTROY
      
      result = CallWindowProc_(oldwinproc, hWnd, uMsg, wParam, lParam)
      
      RemoveProp_(hWnd, "_LIEditOldProc")
      
    Default
      
      result = CallWindowProc_(oldwinproc, hWnd, uMsg, wParam, lParam)
      
  EndSelect
  
  ProcedureReturn result
  
EndProcedure

;==========================================================================================================================
; Window proc of the ListIcon.
;===========================================================================================================================

Procedure.i _LIEListProc(hWnd, uMsg, wParam, lParam)
  
  Protected result, *liedit._LIEdit, PInfo.LVHITTESTINFO, *nmHEADER.HD_NOTIFY, rc.RECT, clientrc.RECT
  
  *liedit = GetProp_(hWnd, "_LIEdit")                                                       ; Retrieve the address of the LIEdit structure.
  
  Select uMsg
      
    Case #WM_NOTIFY
      
      *nmHEADER = lParam
      
      Select *nmHEADER\hdr\code
          
        Case #HDN_BEGINTRACK, #HDN_BEGINTRACKW                                                ; Prevent column 0 from being resized.
          
          If *nmHEADER\iItem = 0
            
            result = 1
            
          EndIf
          
        Default
          
          result = CallWindowProc_(*liedit\listOldProc, hWnd, uMsg, wParam, lParam)
          
      EndSelect
      
    Case #WM_LBUTTONDBLCLK
      
      PInfo\pt\x = lParam & $ffff                                                           ; Identify the clicked item
      
      PInfo\pt\y = (lParam >> 16) & $ffff
      
      SendMessage_(hwnd, #LVM_SUBITEMHITTEST, 0, PInfo)
      
      If PInfo\iItem <> -1                                                                    ; A valid cell was clicked.
        
        *liedit\item = PInfo\iItem
        
        *liedit\subitem = PInfo\iSubItem
        
        ; scroll the listicon if the clicked cell is not entirely visible
        
        ; *****IF YOU WISH TO RESTRICT WHICH CELLS CAN BE EDITED, THEN PERFORM THE NECESSARY CHECKS HERE
        
        ; *****ON THE VALUES OF *liedit\item and *liedit\subitem (WHICH INDICATE WHICH CELL IS ABOUT
        
        ; *****TO BE EDITED) AND RUN THE FOLLOWING 2 LINES FOR THOSE CELLS WHICH ARE TO BE EDITED.
        
        rc\top = *liedit\subitem
        
        rc\left = #LVIR_BOUNDS
        
        SendMessage_(hWnd, #LVM_GETSUBITEMRECT, *liedit\item, rc)
        
        GetClientRect_(hWnd, clientrc)
        
        If rc\left < 0 Or (rc\right - rc\left) > = clientrc\right
          
          SendMessage_(hWnd, #LVM_SCROLL, rc\left, 0)
          
        Else
          
          If rc\right > clientrc\right
            
            SendMessage_(hWnd, #LVM_SCROLL,rc\right - clientrc\right, 0)
            
          EndIf
          
        EndIf
        
        SetWindowLongPtr_(hWnd, #GWL_STYLE, GetWindowLongPtr_(hWnd, #GWL_STYLE) | #LVS_EDITLABELS)
        
        SendMessage_(hWnd, #LVM_EDITLABEL, PInfo\iItem, 0)
        
        ;*****************************************************************************************
        
      EndIf
      
    Case #WM_NCDESTROY
      
      result = CallWindowProc_(*liedit\listOldProc, hWnd, uMsg, wParam, lParam)
      
      RemoveProp_(hWnd, "_LIEdit")
      
      FreeMemory(*liedit)
      
    Default
      
      result=CallWindowProc_(*liedit\listOldProc, hWnd, uMsg, wParam, lParam)
      
  EndSelect
  
  ProcedureReturn result
  
EndProcedure

;===========================================================================================================================
; Window proc of the edit control.
;===========================================================================================================================

Procedure.i _LIEeditProc(hWnd, uMsg, wParam, lParam)
  
  Protected result, oldwinproc, *liedit._LIEdit, *wpos.WINDOWPOS
  
  oldwinproc = GetProp_(hWnd, "_LIEditOldProc")                                             ; Retrieve the address of the old proc.
  
  *liedit = GetProp_(GetParent_(hWnd), "_LIEdit")                                           ; Retrieve the address of the LIEdit structure.
  
  Select uMsg
      
    Case #WM_ERASEBKGND
      
      result = CallWindowProc_(oldwinproc, hWnd, uMsg, wParam, lParam)                          ; A hack in order to clear the default selection of characters.
      
      If *liedit\editHwnd = 0
        
        *liedit\editHwnd = hWnd
        
        SendMessage_(hWnd, #EM_SETMARGINS, #EC_LEFTMARGIN | #EC_RIGHTMARGIN, 4)                 ; Set margins.
        
        SendMessage_(hWnd, #EM_SETSEL, -1, 0)
        
      EndIf
      
    Case #WM_WINDOWPOSCHANGING
      
      *wpos = lParam
      
      *wpos\cx = *liedit\cx                                                                     ; Comment this line to get an edit control which grows with the text.
      
      *wpos\cy = *liedit\cy + 3
      
      *wpos\x  = *liedit\x
      
      *wpos\y  = *liedit\y - 2
      
      result = CallWindowProc_(oldwinproc, hWnd, uMsg, wParam, lParam)
      
    Case #WM_NCDESTROY
      
      result = CallWindowProc_(oldwinproc, hWnd, uMsg, wParam, lParam)
      
      RemoveProp_(hWnd, "_LIEditOldProc")
      
      InvalidateRect_(GetParent_(hWnd), 0, 0)
      
    Default
      
      result = CallWindowProc_(oldwinproc, hWnd, uMsg, wParam, lParam)
      
  EndSelect
  
  ProcedureReturn result
  
EndProcedure

;===========================================================================================================================
; 
;===========================================================================================================================

DisableExplicit

; IDE Options = PureBasic 5.11 (Windows - x86)
; CursorPosition = 423
; Folding = -
; DisableDebugger
; HideErrorLog