
;==========================================================================================================================
; Need a unicode aware version of the API directory creator
;==========================================================================================================================

Import "shell32.lib"
  SHCreateDirectory(*hwnd, pszPath.p-unicode)
EndImport

;==========================================================================================================================
; Generic program data structures
;==========================================================================================================================

Structure ProgramData                                                                   ; Program data structure
  QuitValue.i                                                                           ; Program quit value
  WindowMutex.i                                                                         ; Window lock mutex
  LastWindow.s                                                                          ; The last window opened
  CurrentLine.i                                                                         ; Currently selected line

  CurrentDirectory.s                                                                    ; Current program directory
  ImageDirectory.s                                                                      ; Current program image directory
  IncludeDirectory.s                                                                    ; Current program include files
EndStructure                                                                            ; 

;==========================================================================================================================
; Tooltip structure data
;==========================================================================================================================

Structure ToolTipData                                                                     ; If any tooltips setup, keep track of gadgets that have them so you can remove them if needed
  Window.i                                                                                ; Window being added to
  Gadget.i                                                                                ; Gadget being added to on the window
  Handle.i                                                                                ; Handle of the new tooltip
EndStructure                                                                              ; 

;==========================================================================================================================
; Get working directories
;==========================================================================================================================

Program\CurrentDirectory    = GetCurrentDirectory()
Program\ProjectDirectory    = Program\CurrentDirectory + "Project\"
Program\ImageDirectory      = Program\ProjectDirectory + "Images\"
Program\ModuleDirectory     = Program\ProjectDirectory + "Includes\"

;==========================================================================================================================
; Create the program's working directories if you can
;==========================================================================================================================

MakeSureDirectoryPathExists(Program\ProjectDirectory)                                     ; 
MakeSureDirectoryPathExists(Program\ImageDirectory)                                       ; 
MakeSureDirectoryPathExists(Program\ModuleDirectory)                                      ; 

;==========================================================================================================================
; Keyboard shortcut data structure holder
;==========================================================================================================================

Structure KeyData                ; Key Text           ; Key value          ; Key pair      ; Balloon text                                     
; Files Menu
  OpenDatabase.i                 ; Open Database        ; 262223               ; Alt + O         ; Open someone else's database for use               
  ReloadMaster.i                 ; Reload Master        ; 262226               ; Alt + R         ; Reload the master system database                  
  DumpTables.i                   ; Dump Tables          ; 262212               ; Alt + D         ; Dump all the tables to disk                        
  UndumpTables.i                 ; Undump Tables        ; 262229               ; Alt + U         ; Restore all tables from disk                       
  VacuumTables.i                 ; Vacuum Tables        ; 262230               ; Alt + V         ; Vacuum all wasted space from the database          
  ExitProgram.i                  ; Exit Program         ; 262232               ; Alt + X         ; Exit the program immediately                       
; Category Menu
  AddCategory.i                  ; Add Category         ; 393281               ; Ctrl + Alt + A ; Add a new category heading to the address shortcuts list 
  CopyCategory.i                 ; Copy Category        ; 393283               ; Ctrl + Alt + C ; Copy the current formatted address shortcut details to the clipboard 
  DeleteCategory.i               ; Delete Category      ; 393284               ; Ctrl + Alt + D ; Delete the currently highlighted address category from the list 
  EditCategory.i                 ; Edit Category        ; 393285               ; Ctrl + Alt + E ; Edit the currently selected address category       
; Data Menu
  AddPerson.i                    ; Add Person           ; 131137               ; Ctrl + A        ; Add a new address to the database                  
  CopyPerson.i                   ; Copy Person          ; 131139               ; Ctrl + C        ; Copy formatted address to the clipboard            
  DeletePerson.i                 ; Delete Person        ; 131140               ; Ctrl + D        ; Delete the currently selected address              
  EditPerson.i                   ; Edit Person          ; 131141               ; Ctrl + E        ; Edit the currently selected address                
  PrintPerson.i                  ; Print Person         ; 131152               ; Ctrl + P        ; Print the selected addresses                       
  PrintPerson.i                  ; Print Person         ; 131148               ; Ctrl + L        ; Print labels for the selected addresses            
  TagPeople.i                    ; Tag People           ; 131156               ; Ctrl + T        ; Tag all the addresses in the list                  
; Utility Menu
  BackupDatabase.i               ; Backup Database      ; 262210               ; Alt + B         ; Backup the database to a named day of the week copy 
  ExportAddresses.i              ; Export Addresses     ; 262227               ; Alt + S         ; Export all the address to an XML data file         
  ImportAddresses.i              ; Import Addresses     ; 262217               ; Alt + I         ; Import addresses from an XML data file             
  UpdatePostcodes.i              ; Update Postcodes     ; 262224               ; Alt + P         ; Update the old postcodes table from a current Australia Post file 
; Setup Menu
  ShowData.i                     ; Show Data            ; 113                  ; F2              ; Show or hide critical data in the list             
  ShowClock.i                    ; Show Clock           ; 114                  ; F3              ; Show the time clock on the program title bar       
  ShowTooltips.i                 ; Show Tooltips        ; 115                  ; F4              ; Show or hide the program tooltips                  
  MailSetup.i                    ; Mail Setup           ; 116                  ; F5              ; Setup the email server details for outgoing mail   
; Help Menu
  AboutProgram.i                 ; About Program        ; 262209               ; Alt + A         ; About this program                                 
  ShowHelp.i                     ; Show Help            ; 112                  ; F1              ; Show the help file for this program (If any)       
  KeyboardShortcuts.i            ; Keyboard Shortcuts   ; 262219               ; Alt + K         ; Change the default program keyboard shortcuts      
EndStructure

;==========================================================================================================================
; Keyboard shortcuts text holders
;==========================================================================================================================

Structure MenuTextData           ; Key Text           ; Key value          ; Key pair      ; Balloon text                                     
; Files Menu
  OpenDatabase.s                 ; Open Database        ; 262223               ; Alt + O         ; Open someone else's database for use               
  ReloadMaster.s                 ; Reload Master        ; 262226               ; Alt + R         ; Reload the master system database                  
  DumpTables.s                   ; Dump Tables          ; 262212               ; Alt + D         ; Dump all the tables to disk                        
  UndumpTables.s                 ; Undump Tables        ; 262229               ; Alt + U         ; Restore all tables from disk                       
  VacuumTables.s                 ; Vacuum Tables        ; 262230               ; Alt + V         ; Vacuum all wasted space from the database          
  ExitProgram.s                  ; Exit Program         ; 262232               ; Alt + X         ; Exit the program immediately                       
; Category Menu
  AddCategory.s                  ; Add Category         ; 393281               ; Ctrl + Alt + A ; Add a new category heading to the address shortcuts list 
  CopyCategory.s                 ; Copy Category        ; 393283               ; Ctrl + Alt + C ; Copy the current formatted address shortcut details to the clipboard 
  DeleteCategory.s               ; Delete Category      ; 393284               ; Ctrl + Alt + D ; Delete the currently highlighted address category from the list 
  EditCategory.s                 ; Edit Category        ; 393285               ; Ctrl + Alt + E ; Edit the currently selected address category       
; Data Menu
  AddPerson.s                    ; Add Person           ; 131137               ; Ctrl + A        ; Add a new address to the database                  
  CopyPerson.s                   ; Copy Person          ; 131139               ; Ctrl + C        ; Copy formatted address to the clipboard            
  DeletePerson.s                 ; Delete Person        ; 131140               ; Ctrl + D        ; Delete the currently selected address              
  EditPerson.s                   ; Edit Person          ; 131141               ; Ctrl + E        ; Edit the currently selected address                
  PrintPerson.s                  ; Print Person         ; 131152               ; Ctrl + P        ; Print the selected addresses                       
  PrintPerson.s                  ; Print Person         ; 131148               ; Ctrl + L        ; Print labels for the selected addresses            
  TagPeople.s                    ; Tag People           ; 131156               ; Ctrl + T        ; Tag all the addresses in the list                  
; Utility Menu
  BackupDatabase.s               ; Backup Database      ; 262210               ; Alt + B         ; Backup the database to a named day of the week copy 
  ExportAddresses.s              ; Export Addresses     ; 262227               ; Alt + S         ; Export all the address to an XML data file         
  ImportAddresses.s              ; Import Addresses     ; 262217               ; Alt + I         ; Import addresses from an XML data file             
  UpdatePostcodes.s              ; Update Postcodes     ; 262224               ; Alt + P         ; Update the old postcodes table from a current Australia Post file 
; Setup Menu
  ShowData.s                     ; Show Data            ; 113                  ; F2              ; Show or hide critical data in the list             
  ShowClock.s                    ; Show Clock           ; 114                  ; F3              ; Show the time clock on the program title bar       
  ShowTooltips.s                 ; Show Tooltips        ; 115                  ; F4              ; Show or hide the program tooltips                  
  MailSetup.s                    ; Mail Setup           ; 116                  ; F5              ; Setup the email server details for outgoing mail   
; Help Menu
  AboutProgram.s                 ; About Program        ; 262209               ; Alt + A         ; About this program                                 
  ShowHelp.s                     ; Show Help            ; 112                  ; F1              ; Show the help file for this program (If any)       
  KeyboardShortcuts.s            ; Keyboard Shortcuts   ; 262219               ; Alt + K         ; Change the default program keyboard shortcuts      
EndStructure

;==========================================================================================================================
; Balloon tooltips text holders
;==========================================================================================================================

Structure BalloonTipData         ; Key Text           ; Key value          ; Key pair      ; Balloon text                                     
; Files Menu
  OpenDatabase.s                 ; Open Database        ; 262223               ; Alt + O         ; Open someone else's database for use               
  ReloadMaster.s                 ; Reload Master        ; 262226               ; Alt + R         ; Reload the master system database                  
  DumpTables.s                   ; Dump Tables          ; 262212               ; Alt + D         ; Dump all the tables to disk                        
  UndumpTables.s                 ; Undump Tables        ; 262229               ; Alt + U         ; Restore all tables from disk                       
  VacuumTables.s                 ; Vacuum Tables        ; 262230               ; Alt + V         ; Vacuum all wasted space from the database          
  ExitProgram.s                  ; Exit Program         ; 262232               ; Alt + X         ; Exit the program immediately                       
; Category Menu
  AddCategory.s                  ; Add Category         ; 393281               ; Ctrl + Alt + A ; Add a new category heading to the address shortcuts list 
  CopyCategory.s                 ; Copy Category        ; 393283               ; Ctrl + Alt + C ; Copy the current formatted address shortcut details to the clipboard 
  DeleteCategory.s               ; Delete Category      ; 393284               ; Ctrl + Alt + D ; Delete the currently highlighted address category from the list 
  EditCategory.s                 ; Edit Category        ; 393285               ; Ctrl + Alt + E ; Edit the currently selected address category       
; Data Menu
  AddPerson.s                    ; Add Person           ; 131137               ; Ctrl + A        ; Add a new address to the database                  
  CopyPerson.s                   ; Copy Person          ; 131139               ; Ctrl + C        ; Copy formatted address to the clipboard            
  DeletePerson.s                 ; Delete Person        ; 131140               ; Ctrl + D        ; Delete the currently selected address              
  EditPerson.s                   ; Edit Person          ; 131141               ; Ctrl + E        ; Edit the currently selected address                
  PrintPerson.s                  ; Print Person         ; 131152               ; Ctrl + P        ; Print the selected addresses                       
  PrintPerson.s                  ; Print Person         ; 131148               ; Ctrl + L        ; Print labels for the selected addresses            
  TagPeople.s                    ; Tag People           ; 131156               ; Ctrl + T        ; Tag all the addresses in the list                  
; Utility Menu
  BackupDatabase.s               ; Backup Database      ; 262210               ; Alt + B         ; Backup the database to a named day of the week copy 
  ExportAddresses.s              ; Export Addresses     ; 262227               ; Alt + S         ; Export all the address to an XML data file         
  ImportAddresses.s              ; Import Addresses     ; 262217               ; Alt + I         ; Import addresses from an XML data file             
  UpdatePostcodes.s              ; Update Postcodes     ; 262224               ; Alt + P         ; Update the old postcodes table from a current Australia Post file 
; Setup Menu
  ShowData.s                     ; Show Data            ; 113                  ; F2              ; Show or hide critical data in the list             
  ShowClock.s                    ; Show Clock           ; 114                  ; F3              ; Show the time clock on the program title bar       
  ShowTooltips.s                 ; Show Tooltips        ; 115                  ; F4              ; Show or hide the program tooltips                  
  MailSetup.s                    ; Mail Setup           ; 116                  ; F5              ; Setup the email server details for outgoing mail   
; Help Menu
  AboutProgram.s                 ; About Program        ; 262209               ; Alt + A         ; About this program                                 
  ShowHelp.s                     ; Show Help            ; 112                  ; F1              ; Show the help file for this program (If any)       
  KeyboardShortcuts.s            ; Keyboard Shortcuts   ; 262219               ; Alt + K         ; Change the default program keyboard shortcuts      
EndStructure

;==========================================================================================================================
; Global variables
;==========================================================================================================================

Global Program.ProgramData                                                           ; All my program variables
Global Keys.KeyData                                                                  ; All my keyboard shortcuts
Global MenuText.MenuTextData                                                         ; All repeated menu texts
Global ToolTip.BalloonTipData                                                        ; All repeated balloon tip texts

;==========================================================================================================================
; Short form keyboard shortcut menu text explanations
;==========================================================================================================================

; Files Menu
MenuText\OpenDatabase           = "Open Database"      ; Open Database        ; 262223               ; Alt + O         ; Open someone else's database for use               
MenuText\ReloadMaster           = "Reload Master"      ; Reload Master        ; 262226               ; Alt + R         ; Reload the master system database                  
MenuText\DumpTables             = "Dump Tables"        ; Dump Tables          ; 262212               ; Alt + D         ; Dump all the tables to disk                        
MenuText\UndumpTables           = "Undump Tables"      ; Undump Tables        ; 262229               ; Alt + U         ; Restore all tables from disk                       
MenuText\VacuumTables           = "Vacuum Tables"      ; Vacuum Tables        ; 262230               ; Alt + V         ; Vacuum all wasted space from the database          
MenuText\ExitProgram            = "Exit Program"       ; Exit Program         ; 262232               ; Alt + X         ; Exit the program immediately                       
; Category Menu
MenuText\AddCategory            = "Add Category"       ; Add Category         ; 393281               ; Ctrl + Alt + A ; Add a new category heading to the address shortcuts list 
MenuText\CopyCategory           = "Copy Category"      ; Copy Category        ; 393283               ; Ctrl + Alt + C ; Copy the current formatted address shortcut details to the clipboard 
MenuText\DeleteCategory         = "Delete Category"    ; Delete Category      ; 393284               ; Ctrl + Alt + D ; Delete the currently highlighted address category from the list 
MenuText\EditCategory           = "Edit Category"      ; Edit Category        ; 393285               ; Ctrl + Alt + E ; Edit the currently selected address category       
; Data Menu
MenuText\AddPerson              = "Add Person"         ; Add Person           ; 131137               ; Ctrl + A        ; Add a new address to the database                  
MenuText\CopyPerson             = "Copy Person"        ; Copy Person          ; 131139               ; Ctrl + C        ; Copy formatted address to the clipboard            
MenuText\DeletePerson           = "Delete Person"      ; Delete Person        ; 131140               ; Ctrl + D        ; Delete the currently selected address              
MenuText\EditPerson             = "Edit Person"        ; Edit Person          ; 131141               ; Ctrl + E        ; Edit the currently selected address                
MenuText\PrintPerson            = "Print Person"       ; Print Person         ; 131152               ; Ctrl + P        ; Print the selected addresses                       
MenuText\PrintPerson            = "Print Person"       ; Print Person         ; 131148               ; Ctrl + L        ; Print labels for the selected addresses            
MenuText\TagPeople              = "Tag People"         ; Tag People           ; 131156               ; Ctrl + T        ; Tag all the addresses in the list                  
; Utility Menu
MenuText\BackupDatabase         = "Backup Database"    ; Backup Database      ; 262210               ; Alt + B         ; Backup the database to a named day of the week copy 
MenuText\ExportAddresses        = "Export Addresses"   ; Export Addresses     ; 262227               ; Alt + S         ; Export all the address to an XML data file         
MenuText\ImportAddresses        = "Import Addresses"   ; Import Addresses     ; 262217               ; Alt + I         ; Import addresses from an XML data file             
MenuText\UpdatePostcodes        = "Update Postcodes"   ; Update Postcodes     ; 262224               ; Alt + P         ; Update the old postcodes table from a current Australia Post file 
; Setup Menu
MenuText\ShowData               = "Show Data"          ; Show Data            ; 113                  ; F2              ; Show or hide critical data in the list             
MenuText\ShowClock              = "Show Clock"         ; Show Clock           ; 114                  ; F3              ; Show the time clock on the program title bar       
MenuText\ShowTooltips           = "Show Tooltips"      ; Show Tooltips        ; 115                  ; F4              ; Show or hide the program tooltips                  
MenuText\MailSetup              = "Mail Setup"         ; Mail Setup           ; 116                  ; F5              ; Setup the email server details for outgoing mail   
; Help Menu
MenuText\AboutProgram           = "About Program"      ; About Program        ; 262209               ; Alt + A         ; About this program                                 
MenuText\ShowHelp               = "Show Help"          ; Show Help            ; 112                  ; F1              ; Show the help file for this program (If any)       
MenuText\KeyboardShortcuts      = "Keyboard Shortcuts" ; Keyboard Shortcuts   ; 262219               ; Alt + K         ; Change the default program keyboard shortcuts      

;==========================================================================================================================
; Long winded balloon tooltip text
;==========================================================================================================================

; Files Menu
BalloonText\OpenDatabase        = "Open someone else's database for use"                               ; Open Database        ; 262223               ; Alt + O         ; Open someone else's database for use               
BalloonText\ReloadMaster        = "Reload the master system database"                                  ; Reload Master        ; 262226               ; Alt + R         ; Reload the master system database                  
BalloonText\DumpTables          = "Dump all the tables to disk"                                        ; Dump Tables          ; 262212               ; Alt + D         ; Dump all the tables to disk                        
BalloonText\UndumpTables        = "Restore all tables from disk"                                       ; Undump Tables        ; 262229               ; Alt + U         ; Restore all tables from disk                       
BalloonText\VacuumTables        = "Vacuum all wasted space from the database"                          ; Vacuum Tables        ; 262230               ; Alt + V         ; Vacuum all wasted space from the database          
BalloonText\ExitProgram         = "Exit the program immediately"                                       ; Exit Program         ; 262232               ; Alt + X         ; Exit the program immediately                       
; Category Menu
BalloonText\AddCategory         = "Add a new category heading to the address shortcuts list"           ; Add Category         ; 393281               ; Ctrl + Alt + A ; Add a new category heading to the address shortcuts list 
BalloonText\CopyCategory        = "Copy the current formatted address shortcut details to the clipboard" ; Copy Category        ; 393283               ; Ctrl + Alt + C ; Copy the current formatted address shortcut details to the clipboard 
BalloonText\DeleteCategory      = "Delete the currently highlighted address category from the list"    ; Delete Category      ; 393284               ; Ctrl + Alt + D ; Delete the currently highlighted address category from the list 
BalloonText\EditCategory        = "Edit the currently selected address category"                       ; Edit Category        ; 393285               ; Ctrl + Alt + E ; Edit the currently selected address category       
; Data Menu
BalloonText\AddPerson           = "Add a new address to the database"                                  ; Add Person           ; 131137               ; Ctrl + A        ; Add a new address to the database                  
BalloonText\CopyPerson          = "Copy formatted address to the clipboard"                            ; Copy Person          ; 131139               ; Ctrl + C        ; Copy formatted address to the clipboard            
BalloonText\DeletePerson        = "Delete the currently selected address"                              ; Delete Person        ; 131140               ; Ctrl + D        ; Delete the currently selected address              
BalloonText\EditPerson          = "Edit the currently selected address"                                ; Edit Person          ; 131141               ; Ctrl + E        ; Edit the currently selected address                
BalloonText\PrintPerson         = "Print the selected addresses"                                       ; Print Person         ; 131152               ; Ctrl + P        ; Print the selected addresses                       
BalloonText\PrintPerson         = "Print labels for the selected addresses"                            ; Print Person         ; 131148               ; Ctrl + L        ; Print labels for the selected addresses            
BalloonText\TagPeople           = "Tag all the addresses in the list"                                  ; Tag People           ; 131156               ; Ctrl + T        ; Tag all the addresses in the list                  
; Utility Menu
BalloonText\BackupDatabase      = "Backup the database to a named day of the week copy"                ; Backup Database      ; 262210               ; Alt + B         ; Backup the database to a named day of the week copy 
BalloonText\ExportAddresses     = "Export all the address to an XML data file"                         ; Export Addresses     ; 262227               ; Alt + S         ; Export all the address to an XML data file         
BalloonText\ImportAddresses     = "Import addresses from an XML data file"                             ; Import Addresses     ; 262217               ; Alt + I         ; Import addresses from an XML data file             
BalloonText\UpdatePostcodes     = "Update the old postcodes table from a current Australia Post file" ; Update Postcodes     ; 262224               ; Alt + P         ; Update the old postcodes table from a current Australia Post file 
; Setup Menu
BalloonText\ShowData            = "Show or hide critical data in the list"                             ; Show Data            ; 113                  ; F2              ; Show or hide critical data in the list             
BalloonText\ShowClock           = "Show the time clock on the program title bar"                       ; Show Clock           ; 114                  ; F3              ; Show the time clock on the program title bar       
BalloonText\ShowTooltips        = "Show or hide the program tooltips"                                  ; Show Tooltips        ; 115                  ; F4              ; Show or hide the program tooltips                  
BalloonText\MailSetup           = "Setup the email server details for outgoing mail"                   ; Mail Setup           ; 116                  ; F5              ; Setup the email server details for outgoing mail   
; Help Menu
BalloonText\AboutProgram        = "About this program"                                                 ; About Program        ; 262209               ; Alt + A         ; About this program                                 
BalloonText\ShowHelp            = "Show the help file for this program (If any)"                       ; Show Help            ; 112                  ; F1              ; Show the help file for this program (If any)       
BalloonText\KeyboardShortcuts  = "Change the default program keyboard shortcuts"                      ; Keyboard Shortcuts   ; 262219               ; Alt + K         ; Change the default program keyboard shortcuts      

;==========================================================================================================================
; Keyboard shortcuts data section
;==========================================================================================================================

Enumeration #GadgetIndex

  ; Main program GUI shortcuts

; Files Menu
  #ShortCut_OpenDatabase
  #ShortCut_ReloadMaster
  #ShortCut_DumpTables
  #ShortCut_UndumpTables
  #ShortCut_VacuumTables
  #ShortCut_ExitProgram
; Category Menu
  #ShortCut_AddCategory
  #ShortCut_CopyCategory
  #ShortCut_DeleteCategory
  #ShortCut_EditCategory
; Data Menu
  #ShortCut_AddPerson
  #ShortCut_CopyPerson
  #ShortCut_DeletePerson
  #ShortCut_EditPerson
  #ShortCut_PrintPerson
  #ShortCut_PrintPerson
  #ShortCut_TagPeople
; Utility Menu
  #ShortCut_BackupDatabase
  #ShortCut_ExportAddresses
  #ShortCut_ImportAddresses
  #ShortCut_UpdatePostcodes
; Setup Menu
  #ShortCut_ShowData
  #ShortCut_ShowClock
  #ShortCut_ShowTooltips
  #ShortCut_MailSetup
; Help Menu
  #ShortCut_AboutProgram
  #ShortCut_ShowHelp
  #ShortCut_KeyboardShortcuts

  ; Main program GUI menubar constants

; Files Menu
  #MenuBar_OpenDatabase
  #MenuBar_ReloadMaster
  #MenuBar_DumpTables
  #MenuBar_UndumpTables
  #MenuBar_VacuumTables
  #MenuBar_ExitProgram
; Category Menu
  #MenuBar_AddCategory
  #MenuBar_CopyCategory
  #MenuBar_DeleteCategory
  #MenuBar_EditCategory
; Data Menu
  #MenuBar_AddPerson
  #MenuBar_CopyPerson
  #MenuBar_DeletePerson
  #MenuBar_EditPerson
  #MenuBar_PrintPerson
  #MenuBar_PrintPerson
  #MenuBar_TagPeople
; Utility Menu
  #MenuBar_BackupDatabase
  #MenuBar_ExportAddresses
  #MenuBar_ImportAddresses
  #MenuBar_UpdatePostcodes
; Setup Menu
  #MenuBar_ShowData
  #MenuBar_ShowClock
  #MenuBar_ShowTooltips
  #MenuBar_MailSetup
; Help Menu
  #MenuBar_AboutProgram
  #MenuBar_ShowHelp
  #MenuBar_KeyboardShortcuts
EndEnumeration

;==========================================================================================================================
; Menubar icon image constants
;==========================================================================================================================

Enumeration #ImageIndex

  ; Main program MenuBar icon constants

; Files Menu
  #MenuBarIcon_OpenDatabase
  #MenuBarIcon_ReloadMaster
  #MenuBarIcon_DumpTables
  #MenuBarIcon_UndumpTables
  #MenuBarIcon_VacuumTables
  #MenuBarIcon_ExitProgram
; Category Menu
  #MenuBarIcon_AddCategory
  #MenuBarIcon_CopyCategory
  #MenuBarIcon_DeleteCategory
  #MenuBarIcon_EditCategory
; Data Menu
  #MenuBarIcon_AddPerson
  #MenuBarIcon_CopyPerson
  #MenuBarIcon_DeletePerson
  #MenuBarIcon_EditPerson
  #MenuBarIcon_PrintPerson
  #MenuBarIcon_PrintPerson
  #MenuBarIcon_TagPeople
; Utility Menu
  #MenuBarIcon_BackupDatabase
  #MenuBarIcon_ExportAddresses
  #MenuBarIcon_ImportAddresses
  #MenuBarIcon_UpdatePostcodes
; Setup Menu
  #MenuBarIcon_ShowData
  #MenuBarIcon_ShowClock
  #MenuBarIcon_ShowTooltips
  #MenuBarIcon_MailSetup
; Help Menu
  #MenuBarIcon_AboutProgram
  #MenuBarIcon_ShowHelp
  #MenuBarIcon_KeyboardShortcuts
EndEnumeration

;==========================================================================================================================
; Menubar icon images
;==========================================================================================================================

; Files Menu
CatchImage(#MenuBarIcon_OpenDatabase,                               ?_MenuBarIcon_OpenDatabase)
CatchImage(#MenuBarIcon_ReloadMaster,                               ?_MenuBarIcon_ReloadMaster)
CatchImage(#MenuBarIcon_DumpTables,                                 ?_MenuBarIcon_DumpTables)
CatchImage(#MenuBarIcon_UndumpTables,                               ?_MenuBarIcon_UndumpTables)
CatchImage(#MenuBarIcon_VacuumTables,                               ?_MenuBarIcon_VacuumTables)
CatchImage(#MenuBarIcon_ExitProgram,                                ?_MenuBarIcon_ExitProgram)
; Category Menu
CatchImage(#MenuBarIcon_AddCategory,                                ?_MenuBarIcon_AddCategory)
CatchImage(#MenuBarIcon_CopyCategory,                               ?_MenuBarIcon_CopyCategory)
CatchImage(#MenuBarIcon_DeleteCategory,                             ?_MenuBarIcon_DeleteCategory)
CatchImage(#MenuBarIcon_EditCategory,                               ?_MenuBarIcon_EditCategory)
; Data Menu
CatchImage(#MenuBarIcon_AddPerson,                                  ?_MenuBarIcon_AddPerson)
CatchImage(#MenuBarIcon_CopyPerson,                                 ?_MenuBarIcon_CopyPerson)
CatchImage(#MenuBarIcon_DeletePerson,                               ?_MenuBarIcon_DeletePerson)
CatchImage(#MenuBarIcon_EditPerson,                                 ?_MenuBarIcon_EditPerson)
CatchImage(#MenuBarIcon_PrintPerson,                                ?_MenuBarIcon_PrintPerson)
CatchImage(#MenuBarIcon_PrintPerson,                                ?_MenuBarIcon_PrintPerson)
CatchImage(#MenuBarIcon_TagPeople,                                  ?_MenuBarIcon_TagPeople)
; Utility Menu
CatchImage(#MenuBarIcon_BackupDatabase,                             ?_MenuBarIcon_BackupDatabase)
CatchImage(#MenuBarIcon_ExportAddresses,                            ?_MenuBarIcon_ExportAddresses)
CatchImage(#MenuBarIcon_ImportAddresses,                            ?_MenuBarIcon_ImportAddresses)
CatchImage(#MenuBarIcon_UpdatePostcodes,                            ?_MenuBarIcon_UpdatePostcodes)
; Setup Menu
CatchImage(#MenuBarIcon_ShowData,                                   ?_MenuBarIcon_ShowData)
CatchImage(#MenuBarIcon_ShowClock,                                  ?_MenuBarIcon_ShowClock)
CatchImage(#MenuBarIcon_ShowTooltips,                               ?_MenuBarIcon_ShowTooltips)
CatchImage(#MenuBarIcon_MailSetup,                                  ?_MenuBarIcon_MailSetup)
; Help Menu
CatchImage(#MenuBarIcon_AboutProgram,                               ?_MenuBarIcon_AboutProgram)
CatchImage(#MenuBarIcon_ShowHelp,                                   ?_MenuBarIcon_ShowHelp)
CatchImage(#MenuBarIcon_KeyboardShortcuts,                          ?_MenuBarIcon_KeyboardShortcuts)

;==========================================================================================================================
; Menubar icon images
;==========================================================================================================================

DataSection
; Files Menu
  _MenuBarIcon_OpenDatabase:                       IncludeBinary  "Images\MenuBarIcon_OpenDatabase.ico"
  _MenuBarIcon_ReloadMaster:                       IncludeBinary  "Images\MenuBarIcon_ReloadMaster.ico"
  _MenuBarIcon_DumpTables:                         IncludeBinary  "Images\MenuBarIcon_DumpTables.ico"
  _MenuBarIcon_UndumpTables:                       IncludeBinary  "Images\MenuBarIcon_UndumpTables.ico"
  _MenuBarIcon_VacuumTables:                       IncludeBinary  "Images\MenuBarIcon_VacuumTables.ico"
  _MenuBarIcon_ExitProgram:                        IncludeBinary  "Images\MenuBarIcon_ExitProgram.ico"
; Category Menu
  _MenuBarIcon_AddCategory:                        IncludeBinary  "Images\MenuBarIcon_AddCategory.ico"
  _MenuBarIcon_CopyCategory:                       IncludeBinary  "Images\MenuBarIcon_CopyCategory.ico"
  _MenuBarIcon_DeleteCategory:                     IncludeBinary  "Images\MenuBarIcon_DeleteCategory.ico"
  _MenuBarIcon_EditCategory:                       IncludeBinary  "Images\MenuBarIcon_EditCategory.ico"
; Data Menu
  _MenuBarIcon_AddPerson:                          IncludeBinary  "Images\MenuBarIcon_AddPerson.ico"
  _MenuBarIcon_CopyPerson:                         IncludeBinary  "Images\MenuBarIcon_CopyPerson.ico"
  _MenuBarIcon_DeletePerson:                       IncludeBinary  "Images\MenuBarIcon_DeletePerson.ico"
  _MenuBarIcon_EditPerson:                         IncludeBinary  "Images\MenuBarIcon_EditPerson.ico"
  _MenuBarIcon_PrintPerson:                        IncludeBinary  "Images\MenuBarIcon_PrintPerson.ico"
  _MenuBarIcon_PrintPerson:                        IncludeBinary  "Images\MenuBarIcon_PrintPerson.ico"
  _MenuBarIcon_TagPeople:                          IncludeBinary  "Images\MenuBarIcon_TagPeople.ico"
; Utility Menu
  _MenuBarIcon_BackupDatabase:                     IncludeBinary  "Images\MenuBarIcon_BackupDatabase.ico"
  _MenuBarIcon_ExportAddresses:                    IncludeBinary  "Images\MenuBarIcon_ExportAddresses.ico"
  _MenuBarIcon_ImportAddresses:                    IncludeBinary  "Images\MenuBarIcon_ImportAddresses.ico"
  _MenuBarIcon_UpdatePostcodes:                    IncludeBinary  "Images\MenuBarIcon_UpdatePostcodes.ico"
; Setup Menu
  _MenuBarIcon_ShowData:                           IncludeBinary  "Images\MenuBarIcon_ShowData.ico"
  _MenuBarIcon_ShowClock:                          IncludeBinary  "Images\MenuBarIcon_ShowClock.ico"
  _MenuBarIcon_ShowTooltips:                       IncludeBinary  "Images\MenuBarIcon_ShowTooltips.ico"
  _MenuBarIcon_MailSetup:                          IncludeBinary  "Images\MenuBarIcon_MailSetup.ico"
; Help Menu
  _MenuBarIcon_AboutProgram:                       IncludeBinary  "Images\MenuBarIcon_AboutProgram.ico"
  _MenuBarIcon_ShowHelp:                           IncludeBinary  "Images\MenuBarIcon_ShowHelp.ico"
  _MenuBarIcon_KeyboardShortcuts:                  IncludeBinary  "Images\MenuBarIcon_KeyboardShortcuts.ico"
EndDataSection
